Index: class-http.php
===================================================================
--- class-http.php	(revision 22261)
+++ class-http.php	(working copy)
@@ -1073,13 +1073,14 @@
 			$ssl_verify = apply_filters('https_local_ssl_verify', $ssl_verify);
 		elseif ( ! $is_local )
 			$ssl_verify = apply_filters('https_ssl_verify', $ssl_verify);
-
-		// CURLOPT_TIMEOUT and CURLOPT_CONNECTTIMEOUT expect integers. Have to use ceil since
-		// a value of 0 will allow an unlimited timeout.
-		$timeout = (int) ceil( $r['timeout'] );
-		curl_setopt( $handle, CURLOPT_CONNECTTIMEOUT, $timeout );
-		curl_setopt( $handle, CURLOPT_TIMEOUT, $timeout );
-
+		
+		// CURLOPT_TIMEOUT_MS and CURLOPT_CONNECTTIMEOUT_MS expect integers. Have to use ceil
+		// since a value of 0 will allow an unlimited timeout.
+		$timeout = (int) ceil( $r['timeout'] * 1000 );
+		curl_setopt( $handle, CURLOPT_CONNECTTIMEOUT_MS, $timeout);
+		// CURLOPT_TIMEOUT_MS is a string for some reason, it should be 155
+		curl_setopt( $handle, 155, $timeout );
+		
 		curl_setopt( $handle, CURLOPT_URL, $url);
 		curl_setopt( $handle, CURLOPT_RETURNTRANSFER, true );
 		curl_setopt( $handle, CURLOPT_SSL_VERIFYHOST, ( $ssl_verify === true ) ? 2 : false );
